@@ -1,6 +1,16 @@
+from vtkmodules import web
 from vtkmodules.web import render_window_serializer
 from vtkmodules.vtkFiltersGeometry import vtkDataSetSurfaceFilter
 
+# Patch support for BigInt64 (VTK_LONG_LONG)
+# This requires the latest VTK.js
+if len(web.arrayTypesMapping) == 16:
+    # Mapping is done by index of the list
+    web.arrayTypesMapping.append("ll")  # VTK_LONG_LONG            16
+    web.arrayTypesMapping.append("LL")  # VTK_UNSIGNED_LONG_LONG   17
+    web.javascriptMapping["ll"] = "BigInt64Array"
+    web.javascriptMapping["LL"] = "BigUint64Array"
+
 
 def rgb_float_to_hex(r, g, b):
     return f"#{int(r*255):02x}{int(g*255):02x}{int(b*255):02x}"
